@@ -14,6 +14,7 @@ except ImportError:
 class ClientSocketTraffic(traffic.Traffic):
     destination = None
     broadcast = False
+    broadcast_connection_timeout = 0.2
     direction = "<-"
     socketId = ""
     socketType = socket.SOCK_STREAM
@@ -73,7 +74,7 @@ class ClientSocketTraffic(traffic.Traffic):
 
     def readResponses(self, sock):
         if self.broadcast:
-            sock.settimeout(0.5)
+            sock.settimeout(self.broadcast_connection_timeout)
             responses = []
             try:
                 while True:
@@ -97,12 +98,19 @@ class ClientSocketTraffic(traffic.Traffic):
             sock.shutdown(socket.SHUT_WR)
             responses = self.readResponses(sock)
             sock.close()
-            return [ ServerTraffic(response, self.responseFile) for response in responses ]
+            alteredResponses = [ self.applyAlterations(resp) for resp in responses ]
+            return [ ServerTraffic(response, self.responseFile) for response in alteredResponses ]
         except socket.error:
             sys.stderr.write("WARNING: Server process reset the connection while TextTest's 'fake client' was trying to read a response from it!\n")
             sock.close()
             return []
         
+    def makeResponseTraffic(self, rawText, responseClass, rcHandler):
+        if responseClass is ServerTraffic:
+            text = self.applyAlterations(rawText)
+            return super().makeResponseTraffic(text, responseClass, rcHandler)
+        else:
+            return super().makeResponseTraffic(rawText, responseClass, rcHandler)
 
 
 class XmlRpcClientTraffic(ClientSocketTraffic):
